pub fn parse_node_header(block: &[u8]) -> Option<BTreeNodeHeader>Expand description
Parse a node header (bounds-checked). None if the block is too short to hold
the header (never panics).
pub fn parse_node_header(block: &[u8]) -> Option<BTreeNodeHeader>Parse a node header (bounds-checked). None if the block is too short to hold
the header (never panics).